import fs from 'fs'

import backstopCurrentJSON from '../../backstop.json'

import {
	ComponentsLinksProps,
	ScenariosProps,
} from '@/shared/interfaces/backstopScript'

const createBackstopScenarios = (
	componentsLinks: ComponentsLinksProps[] = []
) => {
	const newScenarios: ScenariosProps[] = []

	componentsLinks.forEach((component) => {
		component.links.forEach((story) => {
			const componentName = component.name.toUpperCase()
			const storyName = story.name?.toUpperCase()

			newScenarios.push({
				label: `${componentName} ${storyName}`,
				cookiePath: 'backstop_data/engine_scripts/cookies.json',
				url: story.url,
				referenceUrl: '',
				readyEvent: '',
				readySelector: '#component-container',
				delay: 0,
				hideSelectors: [],
				removeSelectors: [],
				hoverSelector: '',
				clickSelector: '',
				postInteractionWait: 2000,
				selectors: ['#component-container'],
				selectorExpansion: true,
				expect: 0,
				misMatchThreshold: 0.1,
				requireSameDimensions: true,
			})
		})
	})

	backstopCurrentJSON.scenarios = newScenarios

	fs.writeFileSync(
		'backstop.json',
		JSON.stringify(backstopCurrentJSON, null, 2)
	)
}

export default createBackstopScenarios
